@@ -8,7 +8,7 @@ def test_count_books_single_book() -> None:
     references: list[bible.NormalizedReference] = bible.get_references("James 1:4-6")
 
     # When we get the count of books in the references
-    number_of_books: int = bible.count_books(references[0])
+    number_of_books: int = bible.count_books(references[0])  # type: ignore[arg-type]
 
     # Then the count is correct
     assert number_of_books == 1
@@ -21,7 +21,7 @@ def test_count_books_two_books() -> None:
     )
 
     # When we get the count of books in the references
-    number_of_books: int = bible.count_books(references[0])
+    number_of_books: int = bible.count_books(references[0])  # type: ignore[arg-type]
 
     # Then the count is correct
     assert number_of_books == 2
@@ -34,7 +34,7 @@ def test_count_books_multiple_books() -> None:
     )
 
     # When we get the count of books in the references
-    number_of_books: int = bible.count_books(references[0])
+    number_of_books: int = bible.count_books(references[0])  # type: ignore[arg-type]
 
     # Then the count is correct
     assert number_of_books == 5
@@ -58,7 +58,7 @@ def test_count_books_string() -> None:
     reference: str = "Genesis - Deuteronomy, Matthew 19:3 - Mark 6:9, James 1:4-6"
 
     # When we get the count of books in the references
-    number_of_books: int = bible.count_books(reference)
+    number_of_books: int = bible.count_books(reference)  # type: ignore[arg-type]
 
     # Then the count is correct
     assert number_of_books == 5 + 2 + 1
@@ -69,7 +69,9 @@ def test_count_chapters_single_chapter() -> None:
     references: list[bible.NormalizedReference] = bible.get_references("James 1:4-6")
 
     # When we get the count of chapters in the references
-    number_of_chapters: int = bible.count_chapters(references[0])
+    number_of_chapters: int = bible.count_chapters(
+        references[0],  # type: ignore[arg-type]
+    )
 
     # Then the count is correct
     assert number_of_chapters == 1
@@ -80,7 +82,9 @@ def test_count_chapters_two_chapters() -> None:
     references: list[bible.NormalizedReference] = bible.get_references("James 1-2")
 
     # When we get the count of chapters in the references
-    number_of_chapters: int = bible.count_chapters(references[0])
+    number_of_chapters: int = bible.count_chapters(
+        references[0],  # type: ignore[arg-type]
+    )
 
     # Then the count is correct
     assert number_of_chapters == 2
@@ -91,7 +95,9 @@ def test_count_chapters_multiple_chapters() -> None:
     references: list[bible.NormalizedReference] = bible.get_references("James")
 
     # When we get the count of chapters in the references
-    number_of_chapters: int = bible.count_chapters(references[0])
+    number_of_chapters: int = bible.count_chapters(
+        references[0],  # type: ignore[arg-type]
+    )
 
     # Then the count is correct
     assert number_of_chapters == 5
@@ -104,7 +110,9 @@ def test_count_chapters_multiple_books() -> None:
     )
 
     # When we get the count of chapters in the references
-    number_of_chapters: int = bible.count_chapters(references[0])
+    number_of_chapters: int = bible.count_chapters(
+        references[0],  # type: ignore[arg-type]
+    )
 
     # Then the count is correct
     assert number_of_chapters == 1 + 16 + 1
@@ -128,7 +136,7 @@ def test_count_chapters_string() -> None:
     reference: str = "Genesis, Matthew - Acts"
 
     # When we get the count of chapters in the reference
-    number_of_chapters: int = bible.count_chapters(reference)
+    number_of_chapters: int = bible.count_chapters(reference)  # type: ignore[arg-type]
 
     # Then the count is correct
     assert number_of_chapters == 50 + 28 + 16 + 24 + 21 + 28  # 167 total
@@ -139,7 +147,7 @@ def test_count_verses_single_verse() -> None:
     references: list[bible.NormalizedReference] = bible.get_references("Genesis 1:1")
 
     # When we get the count of verses in the references
-    number_of_verses: int = bible.count_verses(references[0])
+    number_of_verses: int = bible.count_verses(references[0])  # type: ignore[arg-type]
 
     # Then the count is correct
     assert number_of_verses == 1
@@ -150,7 +158,7 @@ def test_count_verses_multiple_verses() -> None:
     references: list[bible.NormalizedReference] = bible.get_references("Genesis 1:6-10")
 
     # When we get the count of verses in the references
-    number_of_verses: int = bible.count_verses(references[0])
+    number_of_verses: int = bible.count_verses(references[0])  # type: ignore[arg-type]
 
     # Then the count is correct
     assert number_of_verses == 5
@@ -163,7 +171,7 @@ def test_count_verses_multiple_chapters() -> None:
     )
 
     # When we get the count of verses in the references
-    number_of_verses: int = bible.count_verses(references[0])
+    number_of_verses: int = bible.count_verses(references[0])  # type: ignore[arg-type]
 
     # Then the count is correct
     assert number_of_verses == 46 + 34 + 27
@@ -174,7 +182,7 @@ def test_count_verses_multiple_books() -> None:
     references: list[bible.NormalizedReference] = bible.get_references("1 John - Jude")
 
     # When we get the count of verses in the references
-    number_of_verses: int = bible.count_verses(references[0])
+    number_of_verses: int = bible.count_verses(references[0])  # type: ignore[arg-type]
 
     # Then the count is correct
     assert number_of_verses == (10 + 29 + 24 + 21 + 21) + 13 + 14 + 25
@@ -198,7 +206,7 @@ def test_count_verses_string() -> None:
     reference: str = "Genesis 1:1; John 3:16; Romans 15:5-7,13"
 
     # When we get the count of verses in the reference
-    number_of_verses: int = bible.count_verses(reference)
+    number_of_verses: int = bible.count_verses(reference)  # type: ignore[arg-type]
 
     # Then the count is correct
     assert number_of_verses == 1 + 1 + (3 + 1)
